@@ -4,13 +4,15 @@ use warnings;
 
 package App::MP4Meta::Command::musicvideo;
 {
-  $App::MP4Meta::Command::musicvideo::VERSION = '1.120500';
+  $App::MP4Meta::Command::musicvideo::VERSION = '1.122330';
 }
 
 # ABSTRACT: Apply metadata to a music video. Parses the filename in order to get its artist and title.
 
 use App::MP4Meta -command;
 
+use Try::Tiny;
+
 
 sub usage_desc { "musicvideo %o [file ...]" }
 
@@ -24,6 +26,7 @@ sub opt_spec {
         [ "coverfile=s", "The location of the cover image" ],
         [ "title=s",     "The title of the music video" ],
         [ "noreplace", "Don't replace the file - creates a temp file instead" ],
+        [ "verbose",   "Print verbosely" ],
     );
 }
 
@@ -56,13 +59,25 @@ sub execute {
             genre     => $opt->{genre},
             title     => $opt->{title},
             coverfile => $opt->{coverfile},
+            verbose   => $opt->{verbose},
         }
     );
 
     for my $file (@$args) {
-        my $error = $mv->apply_meta($file);
-        say $error if $error;
+        say "processing $file" if $opt->{verbose};
+        my $error;
+        try {
+            $error = $mv->apply_meta($file);
+        }
+        catch {
+            $error = "Error applying meta to $file: $_";
+        }
+        finally {
+            say $error if $error;
+        };
     }
+
+    say 'done' if $opt->{verbose};
 }
 
 1;
@@ -76,7 +91,7 @@ App::MP4Meta::Command::musicvideo - Apply metadata to a music video. Parses the
 
 =head1 VERSION
 
-version 1.120500
+version 1.122330
 
 =head1 SYNOPSIS
 
@@ -96,7 +111,7 @@ Andrew Jones <andrew@arjones.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Andrew Jones.
+This software is copyright (c) 2012 by Andrew Jones.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
